==> webHotfixV1.2.0_10-14.tar: icpdas/httpd/fw_rtuc/fw_rtuc_action.php <==
<?php
require_once("../page/class.php");

//true表示array型態，false則是物件
$rtuJson = json_decode(file_get_contents(CommonData::$RTUC_CONFIG),false);

//var_dump($rtu_json);
$modifyType = $_POST['modifyType'];

if ($modifyType == "base") { //基本參數(Modify Item)

	$rtuJson->serverIp = $_POST['serverIp'];
	$rtuJson->serverPort = (int)$_POST['serverPort'];
	$rtuJson->buadrate = (int)$_POST['buadrate'];
	$rtuJson->databit = (int)$_POST['databit'];
	$rtuJson->parity = $_POST['parity'];
	$rtuJson->stopbit = (int)$_POST['stopbit'];
	$rtuJson->mbTimeout = (int)$_POST['mbTimeout'];
	$rtuJson->stationId = (int)$_POST['stationId'];
	$rtuJson->deviceType = (int)$_POST['deviceType'];
	$rtuJson->dataTime = (int)$_POST['dataTime'];
	$rtuJson->heartTime = (int)$_POST['heartTime'];

	$goPage = "fw_rtuc.php";
}else if ($modifyType == "mbnumber") { //Modbus Device

	$modifyNumber = $_POST['modifyNumber'];
	$index = $modifyNumber;

    if($modifyNumber == $rtuJson->mbNumber)//data from Add Button
        $rtuJson->mbNumber = $rtuJson->mbNumber+1;
	$rtuJson->mbName[$index] = $_POST['mbName'.$modifyNumber];
	$rtuJson->mbId[$index] = (int)$_POST['mbId'.$modifyNumber];
	$rtuJson->mbIp[$index] = $_POST['mbIp'.$modifyNumber];
	$rtuJson->mbPort[$index] = (int)$_POST['mbPort'.$modifyNumber];
	$rtuJson->diN[$index] = (int)$_POST['diN'.$modifyNumber];
	$rtuJson->doN[$index] = (int)$_POST['doN'.$modifyNumber];
	$rtuJson->aiN[$index] = (int)$_POST['aiN'.$modifyNumber];
	$rtuJson->aoN[$index] = (int)$_POST['aoN'.$modifyNumber];
	$rtuJson->cntN[$index] = (int)$_POST['cntN'.$modifyNumber];
	$rtuJson->diAddress[$index] = (int)$_POST['diAddress'.$modifyNumber];
	$rtuJson->doAddress[$index] = (int)$_POST['doAddress'.$modifyNumber];
	$rtuJson->aiAddress[$index] = (int)$_POST['aiAddress'.$modifyNumber];
	$rtuJson->aoAddress[$index] = (int)$_POST['aoAddress'.$modifyNumber];
	$rtuJson->cntAddress[$index] = (int)$_POST['cntAddress'.$modifyNumber];
	//不管有沒有，先增加一個，再看有幾個來填入
	$rtuJson->aiType[$index][0] = (int)$_POST['aiType'.$modifyNumber];
	$rtuJson->aoType[$index][0] = (int)$_POST['aoType'.$modifyNumber];
	for ($i = 0;$i < $rtuJson->aiN[$index];$i++)
        $rtuJson->aiType[$index][$i] = (int)$_POST['aiType'.$modifyNumber];
	for ($i = 0;$i < $rtuJson->aoN[$index];$i++)
        $rtuJson->aoType[$index][$i] = (int)$_POST['aoType'.$modifyNumber];
	$rtuJson->aiFormat[$index] = (int)$_POST['aiFormat'.$modifyNumber];
	$rtuJson->aoFormat[$index] = (int)$_POST['aoFormat'.$modifyNumber];

	$goPage = "fw_rtuc_mbnumber.php";
}else if ($modifyType == "mbnumber_delete") { //Delete Modbus
	$modifyNumber = $_POST['modifyNumber'];
	$index = $modifyNumber;

	echo "<br>\r\n";
	//$rtuJson->mbNumber = $index;
	$rtuJson->mbNumber = $rtuJson->mbNumber-1;
	array_splice($rtuJson->mbName, $index, 1);
	array_splice($rtuJson->mbId, $index, 1);
	array_splice($rtuJson->mbIp, $index, 1);
	array_splice($rtuJson->mbPort, $index, 1);
	array_splice($rtuJson->diN, $index, 1);
	array_splice($rtuJson->doN, $index, 1);
	array_splice($rtuJson->aiN, $index, 1);
	array_splice($rtuJson->aoN, $index, 1);
	array_splice($rtuJson->cntN, $index, 1);
	array_splice($rtuJson->diAddress, $index, 1);
	array_splice($rtuJson->doAddress, $index, 1);
	array_splice($rtuJson->aiAddress, $index, 1);
	array_splice($rtuJson->aoAddress, $index, 1);
	array_splice($rtuJson->cntAddress, $index, 1);
	array_splice($rtuJson->aiType, $index, 1);
	array_splice($rtuJson->aoType, $index, 1);
	array_splice($rtuJson->aiFormat, $index, 1);
	array_splice($rtuJson->aoFormat, $index, 1);
	$goPage = "fw_rtuc_mbnumber.php";
}else { //其他參數(Modify Item)

	$rtuJson->logTime = (int)$_POST['logTime'];
	$rtuJson->logChangeTime = ((int)$_POST['logChangeTime'])*(60*60);
	$rtuJson->log_dir = $_POST['log_dir'];
	$rtuJson->log_ftpDir = $_POST['log_ftpDir'];
	$rtuJson->log_mailDir = $_POST['log_mailDir'];

	$rtuJson->ftp_serverAddr = $_POST['ftp_serverAddr'];
	$rtuJson->ftp_port = (int)$_POST['ftp_port'];
	$rtuJson->ftp_username = $_POST['ftp_username'];
	$rtuJson->ftp_password = $_POST['ftp_password'];
	$rtuJson->ftp_enable = $_POST['ftp_enable'];

	$rtuJson->email_fromMail = $_POST['email_fromMail'];
	$rtuJson->email_toMails = $_POST['email_toMails'];
	$rtuJson->email_mailServer = $_POST['email_mailServer'];
	$rtuJson->email_mailPort = (int)$_POST['email_mailPort'];
	$rtuJson->email_username = $_POST['email_username'];
	$rtuJson->email_password = $_POST['email_password'];
	$rtuJson->email_max_size = (int)$_POST['email_max_size'];
	$rtuJson->email_enable = $_POST['email_enable'];

	$goPage = "fw_rtuc_otherpara.php";
}

//轉成json型態並儲存
if (file_put_contents(CommonData::$RTUC_CONFIG,json_encode($rtuJson))) {
    //- success --> run rtuc.py
    $enable = $_POST["enable"];
	//-- auto-run manage
	if($enable=="enable")
		$enable="enable";
	else
		$enable="disable";

    $proc_name = CommonData::$RTUC_EXE;
    $full_file_name = CommonData::$RTUC_DIR ."/" .$proc_name;
    addUserProc("RTU Client", CommonData::$RTUC_DIR ."/run_rtuc.sh", CommonData::$RTUC_DIR ."/kill_rtuc.sh", $full_file_name, $enable);
    getUserProcCgf($proc_list);
    setAutoRunFW($proc_list);

    //-- Start/Stop firmware
    $n = count($proc_list);
    for($i=0; $i<$n; $i++)
    {
        if($proc_list[$i]["exec"] == $full_file_name)
        {
            //enable--> restart FW
            if($enable=="enable")
            {
                //-if vxsc running, don't run rtuc
                getVxscInfo($serverIP, $serverPort, $heartbeatTime, $virtualIP, $moduleAlias, $TimeInterval, $UartDataMax
                    , $IsTCP2RTU1, $IsTCP2RTU2, $Baudrate1, $Baudrate2, $Format1, $Format2, $vxsc_enable, $vxsc_alive, $vxsc_version);
                if($vxsc_enable=="enable" || $vxsc_alive == "true")
                {
                    $enable="disable";
                    addUserProc("RTU Client", CommonData::$RTUC_DIR ."/run_rtuc.sh", CommonData::$RTUC_DIR ."/kill_rtuc.sh", $full_file_name, $enable);
                    echo "<script type=\"text/javascript\">";
                    echo "alert('Do not start RTU Client. Please disable VxServer function!!');";
                    echo "</script>";
                }else
                {
                    shell_exec($proc_list[$i]["stop"]);
                    pclose(popen($proc_list[$i]["start"] ." &", "r"));//put into backgroud, or php will be block
                    echo "<div align=\"center\"><font color=\"#0000cc\">Execute ".$proc_list[$i]["name"]." successfully</font><br>\n";
                    //- kill wdtRefresh process
                    wdtOnOff("disable");
                }
                break;
            }else
            {
                shell_exec($proc_list[$i]["stop"]);
                echo "<div align=\"center\"><font color=\"#0000cc\">Stop ".$proc_list[$i]["name"]." successfully</font><br>\n";
                wdtOnOff("enable");
                break;
            }
        }
    }

	echo "<script type=\"text/javascript\">";
	echo "alert('Modify Success!!');";
	echo "window.location.href='".$goPage."';";
	echo "</script>";
}else {
	echo "<script type=\"text/javascript\">";
	echo "alert('Modify Fail!!');";
	echo "window.location.href='".$goPage."';";
	echo "</script>";
}
?>

==> webHotfixV1.3.0_2015-08-25.tar: icpdas/httpd/fw_rtuc/fw_rtuc_action.php <==
<?php
require_once("../page/class.php");

//true表示array型態，false則是物件
$rtuJson = json_decode(file_get_contents(CommonData::$RTUC_CONFIG),false);

//var_dump($rtu_json);
$modifyType = $_POST['modifyType'];

if ($modifyType == "base") { //基本參數(Modify Item)

	$rtuJson->serverIp = $_POST['serverIp'];
	$rtuJson->serverPort = (int)$_POST['serverPort'];
	$rtuJson->buadrate = (int)$_POST['buadrate'];
	$rtuJson->databit = (int)$_POST['databit'];
	$rtuJson->parity = $_POST['parity'];
	$rtuJson->stopbit = (int)$_POST['stopbit'];
	$rtuJson->mbTimeout = (int)$_POST['mbTimeout'];
	$rtuJson->stationId = (int)$_POST['stationId'];
	$rtuJson->deviceType = (int)$_POST['deviceType'];
	$rtuJson->dataTime = (int)$_POST['dataTime'];
	$rtuJson->heartTime = (int)$_POST['heartTime'];

	$goPage = "fw_rtuc.php";
}else if ($modifyType == "mbnumber") { //Modbus Device

	$modifyNumber = $_POST['modifyNumber'];
	$index = $modifyNumber;

    if($modifyNumber == $rtuJson->mbNumber)//data from Add Button
        $rtuJson->mbNumber = $rtuJson->mbNumber+1;
	$rtuJson->mbName[$index] = $_POST['mbName'.$modifyNumber];
	$rtuJson->mbId[$index] = (int)$_POST['mbId'.$modifyNumber];
	$rtuJson->mbIp[$index] = $_POST['mbIp'.$modifyNumber];
	$rtuJson->mbPort[$index] = (int)$_POST['mbPort'.$modifyNumber];
	$rtuJson->diN[$index] = (int)$_POST['diN'.$modifyNumber];
	$rtuJson->doN[$index] = (int)$_POST['doN'.$modifyNumber];
	$rtuJson->aiN[$index] = (int)$_POST['aiN'.$modifyNumber];
	$rtuJson->aoN[$index] = (int)$_POST['aoN'.$modifyNumber];
	$rtuJson->cntN[$index] = (int)$_POST['cntN'.$modifyNumber];
	$rtuJson->diAddress[$index] = (int)$_POST['diAddress'.$modifyNumber];
	$rtuJson->doAddress[$index] = (int)$_POST['doAddress'.$modifyNumber];
	$rtuJson->aiAddress[$index] = (int)$_POST['aiAddress'.$modifyNumber];
	$rtuJson->aoAddress[$index] = (int)$_POST['aoAddress'.$modifyNumber];
	$rtuJson->cntAddress[$index] = (int)$_POST['cntAddress'.$modifyNumber];
	//不管有沒有，先增加一個，再看有幾個來填入
	$rtuJson->aiType[$index][0] = (int)$_POST['aiType'.$modifyNumber];
	$rtuJson->aoType[$index][0] = (int)$_POST['aoType'.$modifyNumber];
	for ($i = 0;$i < $rtuJson->aiN[$index];$i++)
        $rtuJson->aiType[$index][$i] = (int)$_POST['aiType'.$modifyNumber];
	for ($i = 0;$i < $rtuJson->aoN[$index];$i++)
        $rtuJson->aoType[$index][$i] = (int)$_POST['aoType'.$modifyNumber];
	$rtuJson->aiFormat[$index] = (int)$_POST['aiFormat'.$modifyNumber];
	$rtuJson->aoFormat[$index] = (int)$_POST['aoFormat'.$modifyNumber];

	$goPage = "fw_rtuc_mbnumber.php";
}else if ($modifyType == "mbnumber_delete") { //Delete Modbus
	$modifyNumber = $_POST['modifyNumber'];
	$index = $modifyNumber;

	echo "<br>\r\n";
	//$rtuJson->mbNumber = $index;
	$rtuJson->mbNumber = $rtuJson->mbNumber-1;
	array_splice($rtuJson->mbName, $index, 1);
	array_splice($rtuJson->mbId, $index, 1);
	array_splice($rtuJson->mbIp, $index, 1);
	array_splice($rtuJson->mbPort, $index, 1);
	array_splice($rtuJson->diN, $index, 1);
	array_splice($rtuJson->doN, $index, 1);
	array_splice($rtuJson->aiN, $index, 1);
	array_splice($rtuJson->aoN, $index, 1);
	array_splice($rtuJson->cntN, $index, 1);
	array_splice($rtuJson->diAddress, $index, 1);
	array_splice($rtuJson->doAddress, $index, 1);
	array_splice($rtuJson->aiAddress, $index, 1);
	array_splice($rtuJson->aoAddress, $index, 1);
	array_splice($rtuJson->cntAddress, $index, 1);
	array_splice($rtuJson->aiType, $index, 1);
	array_splice($rtuJson->aoType, $index, 1);
	array_splice($rtuJson->aiFormat, $index, 1);
	array_splice($rtuJson->aoFormat, $index, 1);
	$goPage = "fw_rtuc_mbnumber.php";
}else { //其他參數(Modify Item)

	$rtuJson->logTime = (int)$_POST['logTime'];
	$rtuJson->logChangeTime = ((int)$_POST['logChangeTime'])*(60);//unit:minute
	$rtuJson->log_dir = $_POST['log_dir'];
	$rtuJson->log_ftpDir = $_POST['log_ftpDir'];
	$rtuJson->log_mailDir = $_POST['log_mailDir'];

	$rtuJson->ftp_serverAddr = $_POST['ftp_serverAddr'];
	$rtuJson->ftp_port = (int)$_POST['ftp_port'];
	$rtuJson->ftp_username = $_POST['ftp_username'];
	$rtuJson->ftp_password = $_POST['ftp_password'];
	$rtuJson->ftp_enable = $_POST['ftp_enable'];

	$rtuJson->email_fromMail = $_POST['email_fromMail'];
	$rtuJson->email_toMails = $_POST['email_toMails'];
	$rtuJson->email_mailServer = $_POST['email_mailServer'];
	$rtuJson->email_mailPort = (int)$_POST['email_mailPort'];
	$rtuJson->email_username = $_POST['email_username'];
	$rtuJson->email_password = $_POST['email_password'];
	$rtuJson->email_max_size = (int)$_POST['email_max_size'];
	$rtuJson->email_enable = $_POST['email_enable'];

	$goPage = "fw_rtuc_otherpara.php";
}

//轉成json型態並儲存
if (file_put_contents(CommonData::$RTUC_CONFIG,json_encode($rtuJson))) {
    //- success --> run rtuc.py
    $enable = $_POST["enable"];
	//-- auto-run manage
	if($enable=="enable")
		$enable="enable";
	else
		$enable="disable";

    $proc_name = CommonData::$RTUC_EXE;
    $full_file_name = CommonData::$RTUC_DIR ."/" .$proc_name;
    addUserProc("RTU Client", CommonData::$RTUC_DIR ."/run_rtuc.sh", CommonData::$RTUC_DIR ."/kill_rtuc.sh", $full_file_name, $enable);
    getUserProcCgf($proc_list);
    setAutoRunFW($proc_list);

    //-- Start/Stop firmware
    $n = count($proc_list);
    for($i=0; $i<$n; $i++)
    {
        if($proc_list[$i]["exec"] == $full_file_name)
        {
            //enable--> restart FW
            if($enable=="enable")
            {
                //-if vxsc running, don't run rtuc
                getVxscInfo($serverIP, $serverPort, $heartbeatTime, $virtualIP, $moduleAlias, $TimeInterval, $UartDataMax
                    , $IsTCP2RTU1, $IsTCP2RTU2, $Baudrate1, $Baudrate2, $Format1, $Format2, $vxsc_enable, $vxsc_alive, $vxsc_version);
                if($vxsc_enable=="enable" || $vxsc_alive == "true")
                {
                    $enable="disable";
                    addUserProc("RTU Client", CommonData::$RTUC_DIR ."/run_rtuc.sh", CommonData::$RTUC_DIR ."/kill_rtuc.sh", $full_file_name, $enable);
                    echo "<script type=\"text/javascript\">";
                    echo "alert('Do not start RTU Client. Please disable VxServer function!!');";
                    echo "</script>";
                }else
                {
                    shell_exec($proc_list[$i]["stop"]);
                    pclose(popen($proc_list[$i]["start"] ." &", "r"));//put into backgroud, or php will be block
                    echo "<div align=\"center\"><font color=\"#0000cc\">Execute ".$proc_list[$i]["name"]." successfully</font><br>\n";
                    //- kill wdtRefresh process
                    wdtOnOff("disable");
                }
                break;
            }else
            {
                shell_exec($proc_list[$i]["stop"]);
                echo "<div align=\"center\"><font color=\"#0000cc\">Stop ".$proc_list[$i]["name"]." successfully</font><br>\n";
                wdtOnOff("enable");
                break;
            }
        }
    }

	echo "<script type=\"text/javascript\">";
	echo "alert('Modify Success!!');";
	echo "window.location.href='".$goPage."';";
	echo "</script>";
}else {
	echo "<script type=\"text/javascript\">";
	echo "alert('Modify Fail!!');";
	echo "window.location.href='".$goPage."';";
	echo "</script>";
}
?>
